import express, {Request, Response} from 'express';
import {AlbumService} from '../services/album';
import AlbumModel from '../models/album';
import IUser from '../interfaces/IUser';
import UserModel from '../models/user';

export const AlbumController = {
	createAlbum: async (req: express.Request, res: express.Response) => {
		try {
			const {name, year, artist} = req.body;

			await AlbumService.generate({
				name,
				year,
				artist,
				image: req.file?.filename || '',
			})
				.then((result) => {
					return res.send(result);
				})
				.catch((err) => {
					return res.send({error: err.message});
				});
		} catch (err: unknown) {
			res.json({err});
		}
	},
	getAlbums: async (req: express.Request, res: express.Response) => {
		try {
			await AlbumService.get(req.query.artist?.toString())
				.then((result) => {
					return res.send(result);
				})
				.catch((err) => {
					return res.json({err});
				});
		} catch (err: unknown) {
			res.json({err});
		}
	},
	getAlbum: async (req: express.Request, res: express.Response) => {
		try {
			await AlbumService.getById(req.params.id)
				.then((result) => {
					return res.send(result);
				})
				.catch((err) => {
					return res.json({err});
				});
		} catch (err: unknown) {
			res.json({err});
		}
	},
	publishAlbum: async (req: Request, res: Response) => {
		try {
			const id = req.params.id;
			await AlbumModel.findOneAndUpdate({_id: id}, {published: true});
			res.send('Published');
		} catch (err) {
			res.status(500).send(err);
		}
	},
	deleteAlbum: async (req: Request, res: Response) => {
		try {
			const id = req.params.id;
			const user: IUser | null = await UserModel.findById(req.token._id);
			if (user && user.role === 'Admin') {
				await AlbumModel.deleteOne({_id: id});
			}
			res.send('Deleted');
		} catch (err) {
			res.status(500).send(err);
		}
	},
};
