import express, {Request, Response} from 'express';
import {ArtistService} from '../services/artist';
import ArtistModel from '../models/artist';
import UserModel from '../models/user';
import IUser from '../interfaces/IUser';

export const ArtistController = {
	createArtist: async (req: express.Request, res: express.Response) => {
		try {
			const {name, info} = req.body;

			await ArtistService.generate({
				name,
				info,
				photo: req.file?.filename || '',
			})
				.then((result) => {
					return res.send(result);
				})
				.catch((err) => {
					return res.send({error: err.message});
				});
		} catch (err: unknown) {
			res.json({err});
		}
	},
	getArtists: async (req: express.Request, res: express.Response) => {
		try {
			await ArtistService.get()
				.then((result) => {
					res.send(result);
				})
				.catch((err) => {
					res.json({err});
				});
		} catch (err: unknown) {
			res.json({err});
		}
	},
	deleteArtist: async (req: Request, res: Response) => {
		try {
			const id = req.params.id;
			const user: IUser | null = await UserModel.findById(req.token._id);
			if (user && user.role === 'Admin') {
				await ArtistModel.deleteOne({_id: id});
			}
			res.send('Deleted');
		} catch (err) {
			res.status(500).send(err);
		}
	},
	publishArtist: async (req: Request, res: Response) => {
		try {
			const id = req.params.id;
			await ArtistModel.findOneAndUpdate({_id: id}, {published: true});
			res.send('Published');
		} catch (err) {
			res.status(500).send(err);
		}
	},
};
