import express, {Request, Response} from 'express';
import {TrackService} from '../services/tracks';
import IUser from '../interfaces/IUser';
import UserModel from '../models/user';
import TrackModel from '../models/track';

export const TrackController = {
	createTrack: async (req: express.Request, res: express.Response) => {
		try {
			const {name, duration, album} = req.body;

			await TrackService.generate({
				name,
				duration,
				album,
			})
				.then((result) => {
					return res.send(result);
				})
				.catch((err) => {
					return res.send({error: err.message});
				});
		} catch (err: unknown) {
			res.json({err});
		}
	},
	getTracks: async (req: express.Request, res: express.Response) => {
		try {
			await TrackService.get(req.query.album?.toString())
				.then((result) => {
					return res.send(result);
				})
				.catch((err) => {
					return res.json({err});
				});
		} catch (err: unknown) {
			res.json({err});
		}
	},
	deleteTrack: async (req: Request, res: Response) => {
		try {
			const id = req.params.id;
			const user: IUser | null = await UserModel.findById(req.token._id);
			if (user && user.role === 'Admin') {
				await TrackModel.deleteOne({_id: id});
			}
			res.send('Deleted');
		} catch (err) {
			res.status(500).send(err);
		}
	},
	publishTrack: async (req: Request, res: Response) => {
		try {
			const id = req.params.id;
			await TrackModel.findOneAndUpdate({_id: id}, {published: true});
			res.send('Published');
		} catch (err) {
			res.status(500).send(err);
		}
	},
};
