import {Request, Response} from 'express';
import {getErrorMessage} from '../utils/errors.util';
import * as userServices from '../services/user';
import jwt from 'jsonwebtoken';

export const loginOne = async (req: Request, res: Response) => {
	try {
		const foundUser = await userServices.login(req.body);
		res.status(200).send(foundUser);
	} catch (error) {
		return res.status(500).send(getErrorMessage(error));
	}
};

export const registerOne = async (req: Request, res: Response) => {
	try {
		await userServices.register(req.body);
		res.status(200).send('Inserted successfully');
	} catch (error) {
		return res.status(500).send(getErrorMessage(error));
	}
};

export const logout = async (req: Request, res: Response) => {
	try {
		const authHeader = req.headers['authorization'];
		jwt.sign(authHeader!, '', {expiresIn: 1}, (logout, err) => {
			if (logout) {
				res.send('You have been logged out');
			}
		});
	} catch (err: unknown) {
		throw err;
	}
};
