import React, {useEffect, useState} from 'react';
import {Link, useNavigate} from 'react-router-dom';
import {useAppDispatch, useAppSelector} from '../store/hooks';
import {
	logout,
	setLogOut,
	setUserLoggedIn,
	setUserRole,
} from '../features/user/userSlice';
import IUser from '../interfaces/IUser';

const Header = () => {
	const navigate = useNavigate();
	const dispatch = useAppDispatch();
	const {userLoggedIn, userRole} = useAppSelector((state) => state.user);

	const handleLogOut = () => {
		const token: string | null = window.sessionStorage.getItem('token');
		dispatch(setLogOut());
		dispatch(setUserRole('User'));
		if (token) {
			dispatch(logout(token));
		}
		navigate('/');
	};
	useEffect(() => {
		const loggedInUser = localStorage.getItem('user');
		if (loggedInUser) {
			dispatch(setUserLoggedIn(true));
			const foundUser: IUser = JSON.parse(loggedInUser);
			dispatch(setUserRole(foundUser.role));
		}
	}, [dispatch]);
	return (
		<div>
			{!userLoggedIn ? (
				<Link
					to={'login'}
					className="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline"
				>
					sign in
				</Link>
			) : (
				<div className="flex justify-between">
					<Link
						className="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline"
						to={'track-history'}
					>
						Track History
					</Link>
					<Link
						className="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline"
						to={'add-artist'}
					>
						Add Artist
					</Link>
					<Link
						className="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline"
						to={'add-album'}
					>
						Add Album
					</Link>
					<Link
						className="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline"
						to={'add-track'}
					>
						Add Track
					</Link>
					<Link
						className="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline"
						to={'/'}
					>
						HomePage
					</Link>

					<a
						onClick={handleLogOut}
						href="#"
						className="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline"
					>
						Logout
					</a>
				</div>
			)}
		</div>
	);
};

export default Header;
