import React, {ChangeEvent, Fragment, useEffect, useState} from 'react';
import IAlbum from '../interfaces/IAlbum';
import {useAppDispatch, useAppSelector} from '../store/hooks';
import {useNavigate} from 'react-router-dom';
import {getArtists} from '../features/artist/artistSlice';
import {addAlbum} from '../features/album/albumSlice';

const AddAlbum: React.FunctionComponent = (): React.ReactElement => {
	const [newAlbum, setNewAlbum] = useState<IAlbum>({
		name: '',
		year: '',
	} as IAlbum);
	const [file, setFile] = useState<File>();
	const dispatch = useAppDispatch();
	const navigate = useNavigate();
	const {artists} = useAppSelector((state) => state.artist);
	let [artist, setArtist] = useState<string>('');

	useEffect(() => {
		dispatch(getArtists());
	}, [dispatch]);

	const handleChange = (
		e: ChangeEvent<HTMLInputElement | HTMLTextAreaElement>
	) =>
		setNewAlbum((prevState) => ({
			...prevState,
			[e.target.name]: e.target.value,
		}));

	const fileHandler = (event: React.FormEvent) => {
		const files = (event.target as HTMLInputElement).files;

		if (files && files.length > 0) {
			setFile(files[0]);
		}
	};

	const handleSubmit = async (e: React.FormEvent) => {
		e.preventDefault();
		const album = new FormData();
		album.append('name', newAlbum.name);
		album.append('year', newAlbum.year);
		album.append('image', file!);
		album.append('artist', artist);

		await dispatch(addAlbum(album));
		navigate('/');
	};
	return (
		<form
			className="pt-10"
			encType="multipart/form-data"
			onSubmit={handleSubmit}
		>
			<select
				required
				onChange={(e: React.ChangeEvent<HTMLSelectElement>) =>
					setArtist(e.target.value)
				}
			>
				<option value="">Select Artist</option>
				{artists.map((artist) => (
					<Fragment key={artist._id}>
						{artist.published ? (
							<option value={artist._id}>{artist.name}</option>
						) : null}
					</Fragment>
				))}
			</select>
			<label
				htmlFor="small-input"
				className="block mb-2 text-sm font-medium text-gray-900 dark:text-white"
			>
				Small input
			</label>
			<input
				required
				onChange={handleChange}
				value={newAlbum.name}
				placeholder="Album"
				name="name"
				type="text"
				id="small-input"
				className="block w-full p-2 text-gray-900 border border-gray-300 rounded-lg bg-gray-50 sm:text-xs focus:ring-blue-500 focus:border-blue-500 dark:bg-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:text-white dark:focus:ring-blue-500 dark:focus:border-blue-500 "
			/>
			<label
				htmlFor="message"
				className="block mb-2 text-sm font-medium text-gray-900 dark:text-white"
			>
				Your message
			</label>
			<input
				type="number"
				required
				onChange={handleChange}
				value={newAlbum.year}
				id="message"
				name="year"
				className="block w-full p-2 text-gray-900 border border-gray-300 rounded-lg bg-gray-50 sm:text-xs focus:ring-blue-500 focus:border-blue-500 dark:bg-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:text-white dark:focus:ring-blue-500 dark:focus:border-blue-500"
				placeholder="Year"
			></input>

			<label
				className="block mb-2 text-sm font-medium text-gray-900 dark:text-white"
				htmlFor="file_input"
			>
				Upload file
			</label>
			<input
				required
				onChange={fileHandler}
				className="block w-full text-sm text-gray-900 border border-gray-300 rounded-lg cursor-pointer bg-gray-50 dark:text-gray-400 focus:outline-none dark:bg-gray-700 dark:border-gray-600 dark:placeholder-gray-400"
				aria-describedby="file_input_help"
				id="file_input"
				type="file"
			/>
			<p
				className="mt-1 text-sm text-gray-500 dark:text-gray-300"
				id="file_input_help"
			>
				SVG, PNG, JPG or GIF (MAX. 800x400px).
			</p>
			<button type="submit">Submit</button>
		</form>
	);
};

export default AddAlbum;
