import React, {ChangeEvent, useState} from 'react';
import IArtist from '../interfaces/IArtist';
import {useAppDispatch} from '../store/hooks';
import {addArtist} from '../features/artist/artistSlice';
import {useNavigate} from 'react-router-dom';

const AddArtist: React.FunctionComponent = (): React.ReactElement => {
	const [newArtist, setNewArtist] = useState<IArtist>({
		info: '',
		name: '',
	} as IArtist);
	const [file, setFile] = useState<File>();
	const dispatch = useAppDispatch();
	const navigate = useNavigate();

	const handleChange = (
		e: ChangeEvent<HTMLInputElement | HTMLTextAreaElement>
	) =>
		setNewArtist((prevState) => ({
			...prevState,
			[e.target.name]: e.target.value,
		}));

	const fileHandler = (event: React.FormEvent) => {
		const files = (event.target as HTMLInputElement).files;

		if (files && files.length > 0) {
			setFile(files[0]);
		}
	};

	const handleSubmit = async (e: React.FormEvent) => {
		e.preventDefault();
		const artist = new FormData();
		artist.append('name', newArtist.name);
		artist.append('info', newArtist.info);
		console.log(artist);
		artist.append('photo', file!);

		await dispatch(addArtist(artist));
		navigate('/');
	};
	return (
		<form encType="multipart/form-data" onSubmit={handleSubmit}>
			<label
				htmlFor="small-input"
				className="block mb-2 text-sm font-medium text-gray-900 dark:text-white"
			>
				Small input
			</label>
			<input
				required
				onChange={handleChange}
				value={newArtist.name}
				placeholder="Artist"
				name="name"
				type="text"
				id="small-input"
				className="block w-full p-2 text-gray-900 border border-gray-300 rounded-lg bg-gray-50 sm:text-xs focus:ring-blue-500 focus:border-blue-500 dark:bg-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:text-white dark:focus:ring-blue-500 dark:focus:border-blue-500 "
			/>
			<label
				htmlFor="message"
				className="block mb-2 text-sm font-medium text-gray-900 dark:text-white"
			>
				Your message
			</label>
			<textarea
				required
				onChange={handleChange}
				value={newArtist.info}
				id="message"
				name="info"
				className="block p-2.5 w-full text-sm text-gray-900 bg-gray-50 rounded-lg border border-gray-300 focus:ring-blue-500 focus:border-blue-500 dark:bg-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:text-white dark:focus:ring-blue-500 dark:focus:border-blue-500"
				placeholder="Info about artist"
			></textarea>

			<label
				className="block mb-2 text-sm font-medium text-gray-900 dark:text-white"
				htmlFor="file_input"
			>
				Upload file
			</label>
			<input
				required
				onChange={fileHandler}
				className="block w-full text-sm text-gray-900 border border-gray-300 rounded-lg cursor-pointer bg-gray-50 dark:text-gray-400 focus:outline-none dark:bg-gray-700 dark:border-gray-600 dark:placeholder-gray-400"
				aria-describedby="file_input_help"
				id="file_input"
				type="file"
			/>
			<p
				className="mt-1 text-sm text-gray-500 dark:text-gray-300"
				id="file_input_help"
			>
				SVG, PNG, JPG or GIF (MAX. 800x400px).
			</p>
			<button type="submit">Submit</button>
		</form>
	);
};

export default AddArtist;
