import React, {ChangeEvent, Fragment, useEffect, useState} from 'react';
import ITrack from '../interfaces/ITrack';
import {useAppDispatch, useAppSelector} from '../store/hooks';
import {useNavigate, useParams} from 'react-router-dom';
import {getArtists} from '../features/artist/artistSlice';
// import {addTrack} from '../features/track/trackSlice';
import {getAlbums} from '../features/album/albumSlice';
import {addTrack} from '../features/track/trackSlice';

const AddTrack: React.FunctionComponent = (): React.ReactElement => {
	const [newTrack, setNewTrack] = useState<ITrack>({
		name: '',
		duration: '',
	} as ITrack);
	const dispatch = useAppDispatch();
	const navigate = useNavigate();
	const {albums} = useAppSelector((state) => state.album);
	let [album, setAlbum] = useState<string>('');

	useEffect(() => {
		dispatch(getAlbums());
	}, [dispatch]);

	const handleChange = (
		e: ChangeEvent<HTMLInputElement | HTMLTextAreaElement>
	) =>
		setNewTrack((prevState) => ({
			...prevState,
			[e.target.name]: e.target.value,
		}));

	const handleSubmit = async (e: React.FormEvent) => {
		e.preventDefault();
		const data: ITrack = {
			album,
			duration: newTrack.duration,
			name: newTrack.name,
		};
		console.log(data);
		await dispatch(addTrack(data));
		navigate('/');
	};
	return (
		<form
			className="pt-10"
			encType="multipart/form-data"
			onSubmit={handleSubmit}
		>
			<select
				required
				onChange={(e: React.ChangeEvent<HTMLSelectElement>) =>
					setAlbum(e.target.value)
				}
			>
				<option value="">Select Album</option>
				{albums.map((album) => (
					<Fragment key={album._id}>
						{album.published ? (
							<option value={album._id}>{album.name}</option>
						) : null}
					</Fragment>
				))}
			</select>
			<label
				htmlFor="small-input"
				className="block mb-2 text-sm font-medium text-gray-900 dark:text-white"
			>
				Small input
			</label>
			<input
				required
				onChange={handleChange}
				value={newTrack.name}
				placeholder="Track"
				name="name"
				type="text"
				id="small-input"
				className="block w-full p-2 text-gray-900 border border-gray-300 rounded-lg bg-gray-50 sm:text-xs focus:ring-blue-500 focus:border-blue-500 dark:bg-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:text-white dark:focus:ring-blue-500 dark:focus:border-blue-500 "
			/>
			<label
				htmlFor="message"
				className="block mb-2 text-sm font-medium text-gray-900 dark:text-white"
			>
				Your message
			</label>
			<input
				type="number"
				required
				onChange={handleChange}
				value={newTrack.duration}
				id="message"
				name="duration"
				className="block w-full p-2 text-gray-900 border border-gray-300 rounded-lg bg-gray-50 sm:text-xs focus:ring-blue-500 focus:border-blue-500 dark:bg-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:text-white dark:focus:ring-blue-500 dark:focus:border-blue-500"
				placeholder="Duration"
			></input>

			<p
				className="mt-1 text-sm text-gray-500 dark:text-gray-300"
				id="file_input_help"
			>
				SVG, PNG, JPG or GIF (MAX. 800x400px).
			</p>
			<button type="submit">Submit</button>
		</form>
	);
};

export default AddTrack;
