import React, {Fragment, useEffect, useState} from 'react';
import {
	deleteAlbum,
	getAlbumsByQueryParams,
	publishAlbum,
} from '../features/album/albumSlice';
import {useAppDispatch, useAppSelector} from '../store/hooks';
import {useLocation} from 'react-router-dom';
import {useNavigate} from 'react-router-dom';
import IUser from '../interfaces/IUser';

const Albums: React.FunctionComponent = (): React.ReactElement => {
	const {albums} = useAppSelector((state) => state.album);
	const dispatch = useAppDispatch();
	const params = new URLSearchParams(window.location.search);
	const artist = params.get('artist');
	const {state} = useLocation();
	const navigate = useNavigate();
	const [role, setRole] = useState<string>('User');

	useEffect(() => {
		const userRole = localStorage.getItem('userRole');
		if (userRole) {
			setRole(userRole);
		}
		dispatch(getAlbumsByQueryParams(artist!));
	}, [dispatch]);

	const handlePublish = async (id: string) => {
		await dispatch(publishAlbum(id));
		await dispatch(getAlbumsByQueryParams(artist!));
	};

	const handleDelete = async (id: string) => {
		const user = localStorage.getItem('user');
		if (user) {
			const foundUser: IUser = JSON.parse(user);
			await dispatch(deleteAlbum({id, token: foundUser.token!}));
		}
		await dispatch(getAlbumsByQueryParams(artist!));
	};

	return (
		<div>
			<h2 className="mt-0 mb-2 text-4xl font-medium leading-tight ">Albums</h2>
			<h2>{state.artist}</h2>
			<div className="flex flex-wrap gap-10 justify-between ">
				{albums.length ? (
					albums.map((album) => {
						return (
							<Fragment key={album._id}>
								{role === 'User' && !album.published ? null : (
									<div>
										<img
											onClick={() =>
												navigate(
													{pathname: '/tracks', search: `?album=${album._id}`},
													{state: {album: album.name, artist: state.artist}}
												)
											}
											className="w-48 h-48 object-cover "
											src={`${import.meta.env.VITE_MY_URL}/${album.image}`}
											alt={album.name}
										/>
										<p>{album.name}</p>
										<p>{album.year}</p>
										{role === 'Admin' ? (
											<div>
												<button onClick={() => handleDelete(album._id || '')}>
													Delete
												</button>
												{!album.published && (
													<>
														<p>Unpublished</p>
														<button
															onClick={() => handlePublish(album._id || '')}
														>
															Publish
														</button>
													</>
												)}
											</div>
										) : null}
									</div>
								)}
							</Fragment>
						);
					})
				) : (
					<p>No albums yet</p>
				)}
			</div>
		</div>
	);
};

export default Albums;
