import React, {useEffect, useState} from 'react';
import {
	deleteArtist,
	getArtists,
	publishArtist,
} from '../features/artist/artistSlice';
import {useAppDispatch, useAppSelector} from '../store/hooks';
import {useNavigate} from 'react-router-dom';
import Preloader from '../components/UI/Preloader';
import IUser from '../interfaces/IUser';

const HomePage: React.FunctionComponent = (): React.ReactElement => {
	const {loading, artists} = useAppSelector((state) => state.artist);
	const {userRole} = useAppSelector((state) => state.user);

	const dispatch = useAppDispatch();
	const navigate = useNavigate();

	const handleDelete = async (id: string) => {
		const user = localStorage.getItem('user');
		if (user) {
			const foundUser: IUser = JSON.parse(user);
			await dispatch(deleteArtist({id, token: foundUser.token!}));
		}
		await dispatch(getArtists());
	};

	const handlePublish = async (id: string) => {
		await dispatch(publishArtist(id));
		await dispatch(getArtists());
	};
	useEffect(() => {
		dispatch(getArtists());
	}, [dispatch, navigate, userRole]);

	return (
		<div>
			<h2 className="mt-0 mb-2 text-4xl font-medium leading-tight ">Artists</h2>
			<div className="flex flex-wrap gap-10 justify-between ">
				{loading ? (
					<Preloader />
				) : artists.length ? (
					artists.map((artist) => {
						return (
							<div key={artist._id}>
								{userRole === 'Admin' ? (
									<>
										<img
											onClick={() =>
												navigate(
													{
														pathname: '/albums',
														search: `?artist=${artist._id}`,
													},
													{state: {artist: artist.name}}
												)
											}
											className="w-56 h-56 object-cover "
											src={`${import.meta.env.VITE_MY_URL}/${artist.photo}`}
											alt={artist.name}
										/>
										<span className="block">{artist.name}</span>
										{!artist.published && <p>Unpublished</p>}
										<button
											className="block"
											onClick={() => handleDelete(artist._id || '')}
										>
											Delete
										</button>
										{!artist.published && (
											<button onClick={() => handlePublish(artist._id || '')}>
												Publish
											</button>
										)}
									</>
								) : artist.published ? (
									<>
										<img
											onClick={() =>
												navigate(
													{
														pathname: '/albums',
														search: `?artist=${artist._id}`,
													},
													{state: {artist: artist.name}}
												)
											}
											className="w-56 h-56 object-cover "
											src={`${import.meta.env.VITE_MY_URL}/${artist.photo}`}
											alt={artist.name}
										/>
										<span className="block">{artist.name}</span>
										{userRole === 'Admin' && (
											<button onClick={() => handleDelete(artist._id || '')}>
												Delete
											</button>
										)}
									</>
								) : null}
							</div>
						);
					})
				) : (
					<p>No Artist yet</p>
				)}
			</div>
		</div>
	);
};

export default HomePage;
