import React, {Fragment, useEffect, useState} from 'react';
import {useLocation} from 'react-router-dom';
import {addTrackHistory} from '../features/track-history/trackHistorySlice';
import {
	deleteTrack,
	getTracksByQuery,
	publishTrack,
} from '../features/track/trackSlice';
import ITrackHistoryDto from '../interfaces/ITrackHistoryDto';
import {useAppDispatch, useAppSelector} from '../store/hooks';
import IUser from '../interfaces/IUser';

const Tracks: React.FunctionComponent = (): React.ReactElement => {
	const {state} = useLocation();
	const {tracks} = useAppSelector((state) => state.track);
	const dispatch = useAppDispatch();
	const params = new URLSearchParams(window.location.search);
	const album = params.get('album');
	const {userLoggedIn} = useAppSelector((state) => state.user);
	const [role, setRole] = useState<string>('User');

	useEffect(() => {
		const userRole = localStorage.getItem('userRole');
		if (userRole) {
			setRole(userRole);
		}
		dispatch(getTracksByQuery(album!));
	}, [dispatch]);

	const handleClick = async (trackId: string) => {
		const token = window.sessionStorage.getItem('token');
		const data: ITrackHistoryDto = {
			track: trackId,
			token: token!,
		};

		await dispatch(addTrackHistory(data));
	};

	const handleDelete = async (id: string) => {
		const user = localStorage.getItem('user');
		if (user) {
			const foundUser: IUser = JSON.parse(user);
			await dispatch(deleteTrack({id, token: foundUser.token!}));
		}
		await dispatch(getTracksByQuery(album!));
	};

	const handlePublish = async (id: string) => {
		await dispatch(publishTrack(id));
		await dispatch(getTracksByQuery(album!));
	};

	return (
		<div>
			<h2 className="mt-0 mb-2 text-4xl font-medium leading-tight ">Tracks</h2>
			<h2>{state.artist}</h2>
			<h2>{state.album}</h2>
			<div className="flex flex-col gap-6 pt-4">
				{tracks.length ? (
					tracks.map((track) => {
						return (
							<Fragment key={track._id}>
								{role === 'User' && !track.published ? null : (
									<div
										onClick={() =>
											userLoggedIn ? handleClick(track._id!) : undefined
										}
										className="border border-solid color border-black p-4"
									>
										<p>Track number: {track.seq!.toString()}</p>
										<p>Track name: {track.name}</p>
										<p>Track duration: {track.duration}</p>
										{role === 'Admin' ? (
											<div>
												<button onClick={() => handleDelete(track._id || '')}>
													Delete
												</button>
												{!track.published && (
													<>
														<p>Unpublished</p>
														<button
															onClick={() => handlePublish(track._id || '')}
														>
															Publish
														</button>
													</>
												)}
											</div>
										) : null}
									</div>
								)}
							</Fragment>
						);
					})
				) : (
					<p>No Tracks Yet</p>
				)}
			</div>
		</div>
	);
};

export default Tracks;
