import {createAsyncThunk, createSlice} from '@reduxjs/toolkit';
import type {PayloadAction} from '@reduxjs/toolkit';
import axios from 'axios';
import ITrackHistoryDto from '../../interfaces/ITrackHistoryDto';
import ITrackHistory from '../../interfaces/ITrackHistory';

interface TrackHistoryState {
	track: string;
	loading: boolean;
	tracks: ITrackHistory[];
}

const initialState: TrackHistoryState = {
	track: '',
	loading: false,
	tracks: [],
};

export const addTrackHistory = createAsyncThunk(
	'addTrackHistory',
	async (data: ITrackHistoryDto) => {
		try {
			await axios.post(
				`${import.meta.env.VITE_MY_URL}/track_history`,
				{
					track: data.track,
				},
				{
					headers: {
						Authorization: `Bearer ${data.token}`,
					},
				}
			);
		} catch (err: any) {
			console.log(err);
		}
	}
);

export const getTracks = createAsyncThunk(
	'getTracks',
	async (token: string) => {
		try {
			const response = await axios.get(
				`${import.meta.env.VITE_MY_URL}/track_history`,
				{
					headers: {
						Authorization: `Bearer ${token}`,
					},
				}
			);
			return response.data;
		} catch (err: unknown) {
			console.log(err);
		}
	}
);

export const trackHistorySlice = createSlice({
	name: 'trackHistory',
	initialState,
	reducers: {},
	extraReducers: (builder) => {
		builder
			.addCase(addTrackHistory.pending, (state, action) => {
				state.loading = true;
			})
			.addCase(addTrackHistory.rejected, (state, action) => {
				state.loading = false;
			})
			.addCase(addTrackHistory.fulfilled, (state, action) => {
				state.loading = false;
			})
			.addCase(getTracks.pending, (state, action) => {
				state.loading = true;
			})
			.addCase(getTracks.rejected, (state, action) => {
				state.loading = false;
			})
			.addCase(getTracks.fulfilled, (state, action) => {
				state.loading = false;
				state.tracks = action.payload;
				console.log(action.payload);
			});
	},
});

export const {} = trackHistorySlice.actions;

export default trackHistorySlice.reducer;
