import {createAsyncThunk, createSlice} from '@reduxjs/toolkit';
import type {PayloadAction} from '@reduxjs/toolkit';
import {RootState} from '../../store/store';
import axios from 'axios';
import ITrack from '../../interfaces/ITrack';

interface TrackState {
	tracks: ITrack[];
	loading: boolean;
}

const initialState: TrackState = {
	tracks: [],
	loading: false,
};

export const getTracksByQuery = createAsyncThunk(
	'getTracksByQuery',
	async (albumId: string) => {
		const res = await axios.get(`${import.meta.env.VITE_MY_URL}/tracks`, {
			params: {
				album: albumId,
			},
		});
		return res.data;
	}
);

export const addTrack = createAsyncThunk('addTrack', async (data: ITrack) => {
	const response = await axios.post(
		`${import.meta.env.VITE_MY_URL}/tracks`,
		data
	);
	return response.data;
});

export const publishTrack = createAsyncThunk(
	'publishTrack',
	async (id: string) => {
		try {
			const response = await axios.post(
				`${import.meta.env.VITE_MY_URL}/tracks/${id}/publish`
			);
			return response.data;
		} catch (err) {
			console.log(err);
		}
	}
);

export const deleteTrack = createAsyncThunk(
	'deletTrack',
	async (data: {id: string; token: string}) => {
		const response = await axios.delete(
			`${import.meta.env.VITE_MY_URL}/tracks/${data.id}`,
			{
				headers: {
					Authorization: data.token,
				},
			}
		);
		return response.data;
	}
);

export const trackSlice = createSlice({
	name: 'track',
	initialState,
	reducers: {},
	extraReducers: (builder) => {
		builder
			.addCase(getTracksByQuery.pending, (state, action) => {
				state.loading = true;
			})
			.addCase(getTracksByQuery.rejected, (state, action) => {
				state.loading = false;
			})
			.addCase(
				getTracksByQuery.fulfilled,
				(state, {payload}: PayloadAction<ITrack[]>) => {
					state.tracks = payload;
				}
			)
			.addCase(addTrack.pending, (state, action) => {
				state.loading = true;
			})
			.addCase(addTrack.rejected, (state, action) => {
				state.loading = false;
			})
			.addCase(addTrack.fulfilled, (state, action) => {
				state.loading = false;
			})
			.addCase(publishTrack.pending, (state, action) => {
				state.loading = true;
			})
			.addCase(publishTrack.rejected, (state, action) => {
				state.loading = false;
			})
			.addCase(publishTrack.fulfilled, (state, action) => {
				state.loading = false;
			});
	},
});

export const {} = trackSlice.actions;

export const selectAlbums = (state: RootState) => state.track.tracks;

export default trackSlice.reducer;
